@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_001;
 
-use version; our $VERSION = 'v0.4.2';
+use version; our $VERSION = 'v0.5.0';
 
 1;
 __END__
@@ -28,7 +28,10 @@ Full documentation is available on L<http://key-amb.github.io/App-Koyomi-Doc/>.
 
 =head1 SEE ALSO
 
-L<koyomi>
+L<koyomi>,
+L<koyomi-cli>,
+L<App::Koyomi::Worker>,
+L<App::Koyomi::CLI>
 
 =head1 AUTHORS
 
